ToHex

Trait ToHex 

pub trait ToHex {
    // Required method
    fn to_hex(&self) -> String;
}
A trait for converting a value to hexadecimal encoding

Required Methods

fn to_hex(&self) -> String

Converts the value of self to a hex value, returning the owned string.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToHex for [u8]

Source

fn to_hex(&self) -> String

Turn a vector of u8 bytes into a hexadecimal string.

Example
extern crate rustc_serialize;
use rustc_serialize::hex::ToHex;

fn main () {
    let str = [52,32].to_hex();
    println!("{}", str);
}
Source

impl<'a, T: ?Sized + ToHex> ToHex for &'a T

Source

fn to_hex(&self) -> String

Implementors